#include "UARTTools.h"

#define BAUDRATE 57600
#define FPB 12500000

//
// UART Config - Configures the UART1 peripheral
//
void serial_init(void)
{
    U1RXRbits.U1RXR = 0b0111;       //Remap rx pin - C14
    RPC13Rbits.RPC13R = 0b0001;     //Remap tx pin - C13
    
    int brg = (FPB/(BAUDRATE*4))-1;
    U1MODEbits.BRGH = 1;            // High speed mode
    U1BRG = brg;                    // Store the value in the register
    U1MODEbits.PDSEL = 0;           // 8-bit data no parity
    U1MODEbits.STSEL = 0;           // 1 stop bit
    U1MODEbits.UEN = 0b00;          // UxTX and UxRX pins are enabled and used
    U1MODEbits.UARTEN = 1;          // Enable UART RX/TX
    U1STAbits.UTXEN = 1;            // Enable transmitter
    U1STAbits.URXEN = 1;            // Enable receiver
   
}

//
// Get fn - Receives a char over UART
//
uint8_t getu()
{
    while(!U1STAbits.URXDA){}       // Data received yet
    return(U1RXREG);                // Return data in receive buffer
}

//
// Put fn - Transmits a char over UART
//
void putu(uint8_t c)
{
    while(U1STAbits.UTXBF){}        // Wait for transmit buffer to be empty
    U1TXREG = c;                    // Write char to transmit register
}


//
// Print fn - Print data buffer over UART
void serial_print(uint8_t* buff)
{
    uint8_t* ptr;
    for(ptr=buff; ptr<(&buff)[1]; ptr++)
    {
        putu(*ptr);
    }
    
    putu(13);
    putu(10);
    putu(10);
}