#include <stdio.h>
#include <stdlib.h>
#include <xc.h>
#include "spi_tools.h"
#include "adf7030_tools.h"
#include "pin_config.h"
#include <sys/attribs.h>


#include "CS_def_sensor_board.h"
//#include "CS_def_NOT_sensor_board.h"

/*This is the baseline code for transmission without including the sensors.
 * This sends a dummy data packet "payload_100B.txt"
*/

uint8_t payload_buff[] = {
        #include "payload_100B.txt"
    };

uint32_t TX_SIZE;
void setup_adf_tx();

void __ISR (_TIMER_1_VECTOR, IPL7SRS) 
    Timer1Handler(void)
{      
        uint8_t CMDREADY_IDLE = is_CMDREADY_IDLE();
        if(!CMDREADY_IDLE){
            radio_command(PHY_ON);
        }
        else{
            uint32_t status_4byte = read_RnPL(MISC_FW);
            uint8_t CURR_STATE = (status_4byte & 0x00003F00) >> 8;
            if (CURR_STATE != PHY_ON){
                radio_command(PHY_ON);
            }
            else{
                //Sample BNO, Altimeter
                //Write data to payload buffer
                //Write to SD card?
                //flip which buffer is being written to
                
                write_BPL(0,payload_buff,TX_SIZE);                              //Write to payload buffer using pointer 0 bc PTR_TX associated w pointer 0
                radio_command(PHY_TX);                
            }
        }
        IFS0bits.T1IF = 0;
        TMR1 = 0;
}


//Timer1 Set up: ~10ms if PBS is 40MHz
void config_timer1_int()
{   
    IEC0bits.T1IE = 0;      //disable
    IFS0bits.T1IF = 0;      //flag        
    T1CONbits.TON = 0;      //start with timer 1 off
    IPC1bits.T1IP = 7;      //highest priorty  
    T1CONbits.TCS = 0;      //use internal clock    
    T1CONbits.TGATE = 0;    //disable clock gating
    T1CONbits.TCKPS = 0b10; //prescaler set to 1:64
    TMR1 = 0;               //reset timer 1
//    PR1 = 6250;             //timer 1 period value
    PR1 = 2000;
    T1CONbits.TON = 1;      //turn on
    IEC0bits.T1IE = 1;      //enable   
}

void config_general_int()
{
    __builtin_enable_interrupts();  //global interrupt enable
    INTCONbits.MVEC = 1;            //Multi vector interrupt 
}


int main(int argc, char** argv) 
{
    setup_adf_tx();
    write_BPL(0,payload_buff,TX_SIZE);                                          //Write payload_buff to transmit buffer
    config_general_int();
    config_timer1_int();
   
    
    while(1){}
    
    return (EXIT_SUCCESS);
}




void setup_adf_tx()
{
    reset_radio();      
    enableSPICMD();                                                             //Enables SPI commands to be sent to radio
    spi_init();                                                                 //Enable PIC SPI
     
    poll_CMDREADY_IDLE();                                                       //Configure ADF
    configRadio();                                                              //Configure ADF

    TX_SIZE = 100;                                                              //Set TX_SIZE = 100
    write_bits(GENERIC_PKT_BUFF_CFG1,9,0,TX_SIZE);                              //Set TX_SIZE = 100
    write_bits(GENERIC_PKT_FRAME_CFG1,12,0,TX_SIZE);                            // Set Payload Size to TX_SIZE
    
    write_bits(PROFILE_REF_CLK_CFG,1,26,1);                                     //Modify configuration such that CLK_TYPE = 1 (oscillator is XTAL)
    calibrateRadio();                                                           //Write calibration file to memory
    write_RnPL(SM_DATA_CALIBRATION, CAL_ENABLE);
    radio_command(CFG_DEV);                                                     //Send command to do configuration
    poll_CMDREADY_IDLE();                                                       //Wait for CMD_READY, TRANSITION_STATE==IDLE
    radio_command(PHY_ON);                                                      //Sequence to perform calibration
    poll_CMDREADY_IDLE(); 
    radio_command(DO_CAL);
    poll_CMDREADY_IDLE(); 
    write_RnPL(SM_DATA_CALIBRATION, CAL_DISABLE);
    
    uint32_t PTR_TX = read_bits(GENERIC_PKT_BUFF_CFG0,11,11)*4 + 0x20000000;    //READ PTR_TX
    set_pntr(PTR_TX,0);                                                         //set pointer 0 as TX payload pointer
}